==> prism-1.4.0-20250213.021548-2.jar: prism/aws.clj <==
(ns prism.aws
  (:require
    [prism.http :as http]
    [prism.services :as services]))

(defprotocol AwsClient
  (request [_this path request]))

(defrecord ServiceClient [service-kw aws-config]
  AwsClient
  (request [_ path request]
    (->> (assoc request :aws aws-config)
         (services/service-request path))))

(defrecord StaticUrlClient [url aws-config]
  AwsClient
  (request [_ path request]
    (->> (assoc request :aws aws-config
                        :url (str url path))
         http/request)))

(defrecord DynamicUrlClient [->url aws-config]
  AwsClient
  (request [_ path request]
    (->> (assoc request :aws aws-config
                        :url (str (->url aws-config request) path))
         http/request)))

(defn- default-url [{:keys [service region]}]
  (str "https://"
       service
       (when region \.)
       region
       ".amazonaws.com"))

(defn create-client [type client-config]
  (let [aws-config (-> (select-keys client-config [:region :service])
                       (assoc :credentials {:aws/access-key-id     (:access-key client-config)
                                            :aws/secret-access-key (:secret-key client-config)}))]
    (case type
      ::default (->StaticUrlClient (default-url client-config) aws-config)
      ::static-url (->StaticUrlClient (:url client-config) aws-config)
      ::service (->ServiceClient (:consul-service client-config) aws-config)
      ::dynamic (->DynamicUrlClient (:url-fn client-config) aws-config))))

==> prism-1.4.0-20250213.073035-8.jar: prism/aws.clj <==
(ns prism.aws
  (:require
    [prism.http :as http]
    [prism.services :as services]))

(defprotocol AwsClient
  (request [_this path request]))

(defrecord ServiceClient [service-kw aws-config]
  AwsClient
  (request [_ path request]
    (->> (assoc request :aws aws-config)
         (services/service-request service-kw path))))

(defrecord StaticUrlClient [url aws-config]
  AwsClient
  (request [_ path request]
    (->> (assoc request :aws aws-config
                        :url (str url path))
         http/request)))

(defrecord DynamicUrlClient [->url aws-config]
  AwsClient
  (request [_ path request]
    (->> (assoc request :aws aws-config
                        :url (str (->url aws-config request) path))
         http/request)))

(defn- default-url [{:keys [service region]}]
  (str "https://"
       service
       (when region \.)
       region
       ".amazonaws.com"))

(defn create-client [type client-config]
  (let [aws-config (-> (select-keys client-config [:region :service])
                       (assoc :credentials {:aws/access-key-id     (:access-key client-config)
                                            :aws/secret-access-key (:secret-key client-config)}))]
    (case type
      ::default (->StaticUrlClient (default-url client-config) aws-config)
      ::static-url (->StaticUrlClient (:url client-config) aws-config)
      ::service (->ServiceClient (:consul-service client-config) aws-config)
      ::dynamic (->DynamicUrlClient (:url-fn client-config) aws-config))))
